@@ -156,8 +156,8 @@ OPERETO_HOST = opereto_credentials_json['opereto_host']
 ### TBD - Remove basic auth after migration to OAUTH2.0
 def get_opereto_client():
     try:
-        OPERETO_AUTH_TOKEN = opereto_credentials_json['opereto_auth_token']
-        client = OperetoClient(opereto_host=OPERETO_HOST, opereto_auth_token=OPERETO_AUTH_TOKEN)
+        OPERETO_TOKEN = opereto_credentials_json['opereto_token']
+        client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=OPERETO_TOKEN)
     except KeyError:
         opereto_user = opereto_credentials_json['opereto_user']
         opereto_password = opereto_credentials_json['opereto_password']
